"""
Developed by Alex Ermolaev (Abionics)
Email: abionics.dev@gmail.com
License: MIT
"""

from jsonizer.parser import Jsonizer

__version__ = '1.2.0'
